@@ -17,14 +17,14 @@ use tg_utils::{
 
 use tg4::{
     HooksResponse, Member, MemberChangedHookMsg, MemberDiff, MemberListResponse, MemberResponse,
-    Tg4Contract, TotalWeightResponse,
+    Tg4Contract, TotalPointsResponse,
 };
 
 use crate::error::ContractError;
 use crate::functions::PoEFunction;
 use crate::msg::{
-    ExecuteMsg, GroupsResponse, InstantiateMsg, PoEFunctionType, PreauthResponse, QueryMsg,
-    RewardFunctionResponse,
+    ExecuteMsg, GroupsResponse, InstantiateMsg, MixerFunctionResponse, PoEFunctionType,
+    PreauthResponse, QueryMsg,
 };
 use crate::state::{Groups, GROUPS, POE_FUNCTION_TYPE};
 
@@ -102,16 +102,16 @@ fn initialize_members(
     let mut batch = groups.left.list_members(&deps.querier, None, QUERY_LIMIT)?;
     while !batch.is_empty() {
         let last = Some(batch.last().unwrap().addr.clone());
-        // check it's weight in the other group, and calculate/save the mixed weight if in both
+        // check it's points in the other group, and calculate/save the mixed points if in both
         for member in batch.into_iter() {
             let addr = deps.api.addr_validate(&member.addr)?;
             // note that this is a *raw query* and therefore quite cheap compared to a *smart query*
             // like calling `list_members` on the right side as well
             let other = groups.right.is_member(&deps.querier, &addr)?;
             if let Some(right) = other {
-                let weight = poe_function.rewards(member.weight, right)?;
-                total += weight;
-                members().save(deps.storage, &addr, &weight, height)?;
+                let points = poe_function.mix(member.points, right)?;
+                total += points;
+                members().save(deps.storage, &addr, &points, height)?;
             }
         }
         // and get the next page
@@ -197,9 +197,9 @@ pub fn update_members(
     // add all new members and update total
     for change in changes {
         let member_addr = deps.api.addr_validate(&change.key)?;
-        let new_weight = match change.new {
+        let new_points = match change.new {
             Some(x) => match query_group.is_member(&deps.querier, &member_addr)? {
-                Some(y) => Some(poe_function.rewards(x, y)?),
+                Some(y) => Some(poe_function.mix(x, y)?),
                 None => None,
             },
             None => None,
@@ -207,19 +207,19 @@ pub fn update_members(
         let mems = members();
 
         // update the total with changes.
-        // to calculate this, we need to load the old weight before saving the new weight
-        let prev_weight = mems.may_load(deps.storage, &member_addr)?;
-        total -= prev_weight.unwrap_or_default();
-        total += new_weight.unwrap_or_default();
+        // to calculate this, we need to load the old points before saving the new points
+        let prev_points = mems.may_load(deps.storage, &member_addr)?;
+        total -= prev_points.unwrap_or_default();
+        total += new_points.unwrap_or_default();
 
         // store the new value
-        match new_weight {
-            Some(weight) => mems.save(deps.storage, &member_addr, &weight, height)?,
+        match new_points {
+            Some(points) => mems.save(deps.storage, &member_addr, &points, height)?,
             None => mems.remove(deps.storage, &member_addr, height)?,
         };
 
         // return the diff
-        diffs.push(MemberDiff::new(member_addr, prev_weight, new_weight));
+        diffs.push(MemberDiff::new(member_addr, prev_points, new_points));
     }
 
     TOTAL.save(deps.storage, &total)?;
@@ -352,10 +352,10 @@ pub fn query(deps: Deps, _env: Env, msg: QueryMsg) -> StdResult<Binary> {
             at_height: height,
         } => to_binary(&query_member(deps, addr, height)?),
         ListMembers { start_after, limit } => to_binary(&list_members(deps, start_after, limit)?),
-        ListMembersByWeight { start_after, limit } => {
-            to_binary(&list_members_by_weight(deps, start_after, limit)?)
+        ListMembersByPoints { start_after, limit } => {
+            to_binary(&list_members_by_points(deps, start_after, limit)?)
         }
-        TotalWeight {} => to_binary(&query_total_weight(deps)?),
+        TotalPoints {} => to_binary(&query_total_points(deps)?),
         Groups {} => to_binary(&query_groups(deps)?),
         Hooks {} => {
             let hooks = HOOKS.list_hooks(deps.storage)?;
@@ -365,14 +365,14 @@ pub fn query(deps: Deps, _env: Env, msg: QueryMsg) -> StdResult<Binary> {
             let preauths_hooks = PREAUTH_HOOKS.get_auth(deps.storage)?;
             to_binary(&PreauthResponse { preauths_hooks })
         }
-        RewardFunction {
+        MixerFunction {
             stake,
             engagement,
             poe_function,
         } => {
-            let reward = query_reward_function(deps, stake.u64(), engagement.u64(), poe_function)
+            let reward = query_mixer_function(deps, stake.u64(), engagement.u64(), poe_function)
                 .map_err(|err| StdError::generic_err(err.to_string()))?;
-            to_binary(&RewardFunctionResponse { reward })
+            to_binary(&MixerFunctionResponse { points: reward })
         }
         IsSlasher { addr } => {
             let addr = deps.api.addr_validate(&addr)?;
@@ -382,9 +382,9 @@ pub fn query(deps: Deps, _env: Env, msg: QueryMsg) -> StdResult<Binary> {
     }
 }
 
-fn query_total_weight(deps: Deps) -> StdResult<TotalWeightResponse> {
-    let weight = TOTAL.load(deps.storage)?;
-    Ok(TotalWeightResponse { weight })
+fn query_total_points(deps: Deps) -> StdResult<TotalPointsResponse> {
+    let points = TOTAL.load(deps.storage)?;
+    Ok(TotalPointsResponse { points })
 }
 
 fn query_groups(deps: Deps) -> StdResult<GroupsResponse> {
@@ -397,16 +397,16 @@ fn query_groups(deps: Deps) -> StdResult<GroupsResponse> {
 
 fn query_member(deps: Deps, addr: String, height: Option<u64>) -> StdResult<MemberResponse> {
     let addr = deps.api.addr_validate(&addr)?;
-    let weight = match height {
+    let points = match height {
         Some(h) => members().may_load_at_height(deps.storage, &addr, h),
         None => members().may_load(deps.storage, &addr),
     }?;
-    Ok(MemberResponse { weight })
+    Ok(MemberResponse { points })
 }
 
 // settings for pagination
-const MAX_LIMIT: u32 = 30;
-const DEFAULT_LIMIT: u32 = 10;
+const MAX_LIMIT: u32 = 100;
+const DEFAULT_LIMIT: u32 = 30;
 
 fn list_members(
     deps: Deps,
@@ -421,10 +421,10 @@ fn list_members(
         .range(deps.storage, start, None, Order::Ascending)
         .take(limit)
         .map(|item| {
-            let (addr, weight) = item?;
+            let (addr, points) = item?;
             Ok(Member {
                 addr: addr.into(),
-                weight,
+                points,
             })
         })
         .collect();
@@ -432,23 +432,23 @@ fn list_members(
     Ok(MemberListResponse { members: members? })
 }
 
-fn list_members_by_weight(
+fn list_members_by_points(
     deps: Deps,
     start_after: Option<Member>,
     limit: Option<u32>,
 ) -> StdResult<MemberListResponse> {
     let limit = limit.unwrap_or(DEFAULT_LIMIT).min(MAX_LIMIT) as usize;
-    let start = start_after.map(|m| Bound::exclusive((m.weight, m.addr).joined_key()));
+    let start = start_after.map(|m| Bound::exclusive((m.points, m.addr).joined_key()));
     let members: StdResult<Vec<_>> = members()
         .idx
-        .weight
+        .points
         .range(deps.storage, None, start, Order::Descending)
         .take(limit)
         .map(|item| {
-            let (addr, weight) = item?;
+            let (addr, points) = item?;
             Ok(Member {
                 addr: addr.into(),
-                weight,
+                points,
             })
         })
         .collect();
@@ -456,7 +456,7 @@ fn list_members_by_weight(
     Ok(MemberListResponse { members: members? })
 }
 
-pub fn query_reward_function(
+pub fn query_mixer_function(
     deps: Deps,
     stake: u64,
     engagement: u64,
@@ -468,7 +468,7 @@ pub fn query_reward_function(
     }
     .to_poe_fn()?;
 
-    poe_function.rewards(stake, engagement)
+    poe_function.mix(stake, engagement)
 }
 
 #[cfg_attr(not(feature = "library"), entry_point)]
@@ -495,10 +495,10 @@ mod tests {
     const RESERVE: &str = "reserve";
     const SLASHER: &str = "slasher";
 
-    fn member<T: Into<String>>(addr: T, weight: u64) -> Member {
+    fn member<T: Into<String>>(addr: T, points: u64) -> Member {
         Member {
             addr: addr.into(),
-            weight,
+            points,
         }
     }
 
@@ -551,7 +551,7 @@ mod tests {
         let group_id = app.store_code(contract_staking());
         let msg = tg4_stake::msg::InstantiateMsg {
             denom: STAKE_DENOM.to_owned(),
-            tokens_per_weight: Uint128::new(1),
+            tokens_per_point: Uint128::new(1),
             min_bond: Uint128::new(100),
             unbonding_period: 3600,
             admin: admin.clone(),
@@ -573,7 +573,7 @@ mod tests {
         // stake any needed tokens
         for staker in stakers {
             // give them a balance
-            let balance = coins(staker.weight as u128, STAKE_DENOM);
+            let balance = coins(staker.points as u128, STAKE_DENOM);
             let caller = Addr::unchecked(staker.addr);
 
             // they stake to the contract
@@ -638,7 +638,7 @@ mod tests {
         voter4: Option<u64>,
         voter5: Option<u64>,
     ) {
-        let weight = |addr: &str| -> Option<u64> {
+        let points = |addr: &str| -> Option<u64> {
             let o: MemberResponse = app
                 .wrap()
                 .query_wasm_smart(
@@ -649,23 +649,23 @@ mod tests {
                     },
                 )
                 .unwrap();
-            o.weight
+            o.points
         };
 
-        assert_eq!(weight(OWNER), owner);
-        assert_eq!(weight(VOTER1), voter1);
-        assert_eq!(weight(VOTER2), voter2);
-        assert_eq!(weight(VOTER3), voter3);
-        assert_eq!(weight(VOTER4), voter4);
-        assert_eq!(weight(VOTER5), voter5);
+        assert_eq!(points(OWNER), owner);
+        assert_eq!(points(VOTER1), voter1);
+        assert_eq!(points(VOTER2), voter2);
+        assert_eq!(points(VOTER3), voter3);
+        assert_eq!(points(VOTER4), voter4);
+        assert_eq!(points(VOTER5), voter5);
     }
 
     #[test]
     fn basic_init() {
         let stakers = vec![
-            member(OWNER, 88888888888), // 0 weight -> 0 mixed
-            member(VOTER1, 10000),      // 10000 stake, 100 weight -> 1000 mixed
-            member(VOTER3, 7500),       // 7500 stake, 300 weight -> 1500 mixed
+            member(OWNER, 88888888888), // 0 points -> 0 mixed
+            member(VOTER1, 10000),      // 10000 stake, 100 points -> 1000 mixed
+            member(VOTER3, 7500),       // 7500 stake, 300 points -> 1500 mixed
         ];
 
         let mut app = AppBuilder::new_custom().build(|router, _, storage| {
@@ -675,7 +675,7 @@ mod tests {
                     .init_balance(
                         storage,
                         &Addr::unchecked(&staker.addr),
-                        coins(staker.weight as u128, STAKE_DENOM),
+                        coins(staker.points as u128, STAKE_DENOM),
                     )
                     .unwrap();
             }
@@ -699,8 +699,8 @@ mod tests {
     #[test]
     fn update_with_upstream_change() {
         let stakers = vec![
-            member(VOTER1, 10000), // 10000 stake, 100 weight -> 1000 mixed
-            member(VOTER3, 7500),  // 7500 stake, 300 weight -> 1500 mixed
+            member(VOTER1, 10000), // 10000 stake, 100 points -> 1000 mixed
+            member(VOTER3, 7500),  // 7500 stake, 300 points -> 1500 mixed
             member(VOTER5, 50),    // below stake threshold -> None
         ];
 
@@ -716,7 +716,7 @@ mod tests {
                     .init_balance(
                         storage,
                         &Addr::unchecked(&staker.addr),
-                        coins(staker.weight as u128, STAKE_DENOM),
+                        coins(staker.points as u128, STAKE_DENOM),
                     )
                     .unwrap();
             }
@@ -751,7 +751,7 @@ mod tests {
         app.execute_contract(Addr::unchecked(VOTER5), staker_addr, &msg, &balance)
             .unwrap();
 
-        // check updated weights
+        // check updated points
         check_membership(
             &app,
             &mixer_addr,
@@ -771,18 +771,18 @@ mod tests {
             add: vec![
                 Member {
                     addr: VOTER2.into(),
-                    weight: 300,
+                    points: 300,
                 },
                 Member {
                     addr: VOTER3.into(),
-                    weight: 1200,
+                    points: 1200,
                 },
             ],
         };
         app.execute_contract(Addr::unchecked(OWNER), group_addr, &msg, &[])
             .unwrap();
 
-        // check updated weights
+        // check updated points
         check_membership(
             &app,
             &mixer_addr,
@@ -801,8 +801,8 @@ mod tests {
     #[test]
     fn hook_on_engagement() {
         let stakers = vec![
-            member(VOTER1, 10000), // 10000 stake, 100 weight -> 1000 mixed
-            member(VOTER3, 7500),  // 7500 stake, 300 weight -> 1500 mixed
+            member(VOTER1, 10000), // 10000 stake, 100 points -> 1000 mixed
+            member(VOTER3, 7500),  // 7500 stake, 300 points -> 1500 mixed
             member(VOTER5, 50),    // below stake threshold -> None
         ];
 
@@ -818,7 +818,7 @@ mod tests {
                     .init_balance(
                         storage,
                         &Addr::unchecked(&staker.addr),
-                        coins(staker.weight as u128, STAKE_DENOM),
+                        coins(staker.points as u128, STAKE_DENOM),
                     )
                     .unwrap();
             }
@@ -846,11 +846,11 @@ mod tests {
                 add: vec![
                     Member {
                         addr: VOTER2.to_owned(),
-                        weight: 400,
+                        points: 400,
                     },
                     Member {
                         addr: VOTER1.to_owned(),
-                        weight: 8000,
+                        points: 8000,
                     },
                 ],
                 remove: vec![VOTER3.to_owned()],
@@ -875,9 +875,9 @@ mod tests {
     #[test]
     fn slashing_works() {
         let stakers = vec![
-            member(VOTER1, 10000), // 10000 stake, 100 weight -> 1000 mixed
-            member(VOTER2, 20000), // 20000 stake, 200 weight -> 2000 mixed
-            member(VOTER3, 7500),  // 7500 stake, 300 weight -> 1500 mixed
+            member(VOTER1, 10000), // 10000 stake, 100 points -> 1000 mixed
+            member(VOTER2, 20000), // 20000 stake, 200 points -> 2000 mixed
+            member(VOTER3, 7500),  // 7500 stake, 300 points -> 1500 mixed
         ];
 
         let mut app = AppBuilder::new_custom().build(|router, _, storage| {
@@ -892,7 +892,7 @@ mod tests {
                     .init_balance(
                         storage,
                         &Addr::unchecked(&staker.addr),
-                        coins(staker.weight as u128, STAKE_DENOM),
+                        coins(staker.points as u128, STAKE_DENOM),
                     )
                     .unwrap();
             }
